Authors
=======

Development Lead
----------------

* Benjamin Schwarze <benjamin.schwarze@mailboxd.de> (`@benjixx <https://github.com/benjixx>`_)


Contributors
------------

* Eric Van Steenbergen <vs.eric@gmail.com>
* Sebastian May <me@bstr.eu>


Credits
-------

Special thanks goes to the
`requests <https://github.com/kennethreitz/requests>`_ project which heavily
inspired our contribution guidelines.
